# Collection Framework


Takes a string and returns the number of unique characters

##Installations
Install the package

##Example of use
``` 
from collection_framework.cli import get_result

if __name__ == "__main__":
    print(get_result())

```
##Launch
Рass a string as a parameter '--string'
```
python3 {script_name} --string {string}
```
or 
pass the path to the file as a parameter '--file'

    python3 {script_name} --file {path} 
